<?php

namespace Drupal\c2pa_sign\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\file\FileInterface;

/**
 * Wraps an indexing items event.
 */
final class ManifestCreateEvent extends Event {

  const EVENT_NAME = 'c2pa_sign_manifest_create_event';

  /**
   * The manifest to be altered
   *
   * @var array
   */
  protected array $manifest;

  /**
   * The file the manifest is being created for
   *
   * @var \Drupal\file\FileInterface
   */
  protected FileInterface $file;

  /**
   * The entity being acted upon
   */
  protected ContentEntityInterface $entity;

  /**
   * Creates the new class instance
   *
   * @param array $manifest The manifest array to be passed to c2patool as JSON
   */
  public function __construct(array &$manifest, FileInterface $file) {
    $this->manifest = $manifest;
    $this->file = $file;
  }

  /**
   * Set the Entity to be attached to the event.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *
   * @return void
   */
  public function setEntity(ContentEntityInterface $entity) {
    $this->entity = $entity;
  }

  /**
   * Get the Entity attached to the event
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface|false
   */
  public function getEntity() {
    return $this->entity ?? FALSE;
  }

  /**
   * Does the event have an attached Entity?
   *
   * @return bool
   */
  public function hasEntity() {
    return isset($this->entity);
  }

  /**
   * Retrieves the potentially altered manifest
   */
  public function getManifest(): array {
    return $this->manifest;
  }

  /**
   * set the manifest data
   *
   * @param array $manifest
   *
   * @return void
   */
  public function setManifest(array $manifest) {
    $this->manifest = $manifest;
  }

}
